[devscripts] 01/01: debcheckout: Add auth mapping for git://github.com.

myon at debian.org myon at debian.org
Wed Sep 30 09:42:19 UTC 2015


This is an automated email from the git hooks/post-receive script.

myon pushed a commit to branch master
in repository devscripts.

commit fec01a5eb0ca5eca331a6faef674bce343a77662
Author: Christoph Berg <myon at debian.org>
Date:   Wed Sep 30 11:42:14 2015 +0200

    debcheckout: Add auth mapping for git://github.com.
---
 debian/changelog       | 5 ++++-
 scripts/debcheckout.pl | 9 ++++++++-
 2 files changed, 12 insertions(+), 2 deletions(-)

diff --git a/debian/changelog b/debian/changelog
index ea26bb5..2ad4794 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -75,7 +75,10 @@ devscripts (2.15.9) UNRELEASED; urgency=medium
   * debian/lintian-overrides: remove overrides for false positives that had
     been fixed in lintian
 
- -- Joachim Breitner <nomeata at debian.org>  Tue, 11 Aug 2015 21:12:03 +0200
+  [ Christoph Berg ]
+  * debcheckout: Add auth mapping for git://github.com.
+
+ -- Christoph Berg <christoph.berg at credativ.de>  Wed, 30 Sep 2015 11:41:04 +0200
 
 devscripts (2.15.8) unstable; urgency=high
 
diff --git a/scripts/debcheckout.pl b/scripts/debcheckout.pl
index 7e5a1b0..3477f8a 100755
--- a/scripts/debcheckout.pl
+++ b/scripts/debcheckout.pl
@@ -80,6 +80,9 @@ for Subversion repositories hosted on alioth this means that
 S<I<svn+ssh://svn.debian.org/...>> will be used instead of
 S<I<svn://svn.debian.org/...>>.
 
+There are built-in rules for alioth.debian.org and github.com. Other hosts
+can be configured using B<DEBCHECKOUT_AUTH_URLS>.
+
 =item B<-d>, B<--details>
 
 Only print a list of detailed information about the package
@@ -448,13 +451,17 @@ sub set_auth($$$$) {
     my $user_url = $url;
 
     # Adjust urls from new-style anonymous access to old-style and then deal
     # with adjusting for authentication
     $url =~ s@(?:alioth\.debian\.org/(?:anonscm/bzr|scm/loggerhead/bzr)|anonscm\.debian\.org/bzr(?:/bzr)?)@bzr.debian.org/bzr@;
     $url =~ s@(?:alioth\.debian\.org/anonscm/darcs|anonscm\.debian\.org/darcs)@darcs.debian.org/darcs@;
     $url =~ s at git://anonscm\.debian\.org at git://git.debian.org@;
     $url =~ s@(?:alioth\.debian\.org/anonscm/git|anonscm\.debian\.org/git)@git.debian.org/git@;
     $url =~ s@(?:alioth\.debian\.org/anonscm/hg|anonscm\.debian\.org/hg)@hg.debian.org/hg@;
     $url =~ s at svn://(?:scm\.alioth|anonscm)\.debian\.org at svn://svn.debian.org@;
+
+    # other providers
+    $url =~ s!git://github\.com/!git\@github.com:!;
+
     given ($repo_type) {
 	when ("bzr") {
 	    $url =~ s|^[\w+]+://(bzr\.debian\.org)/(.*)|bzr+ssh://$user$1/bzr/$2|;
@@ -448,13 +451,17 @@ sub set_auth($$$$) {
 
     # Adjust urls from new-style anonymous access to old-style and then deal
-    # with adjusting for authentication
+    # with adjusting for authentication on alioth
     $url =~ s@(?:alioth\.debian\.org/(?:anonscm/bzr|scm/loggerhead/bzr)|anonscm\.debian\.org/bzr(?:/bzr)?)@bzr.debian.org/bzr@;
     $url =~ s@(?:alioth\.debian\.org/anonscm/darcs|anonscm\.debian\.org/darcs)@darcs.debian.org/darcs@;

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/collab-maint/devscripts.git



More information about the devscripts-devel mailing list